Changelog — pyttsx v1.0 documentation

### Navigation

- index
- modules |
- previous |
- pyttsx v1.0 documentation »

# Changelog

## Version 1.0

First release.

### Table Of Contents

- Changelog
  - Version 1.0

#### Previous topic

Implementing drivers

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- previous |
- pyttsx v1.0 documentation »

© Copyright 2009, Peter Parente. Created using Sphinx 0.6.2.